Name:		siril
Version:	1.2.5
Release:	%mkrel 2
Summary:	Astronomical image (pre-)processing program
Group:		Sciences/Astronomy
License:	GPLv3+
URL:		https://siril.org/
Source0:	https://free-astro.org/download/%{name}-%{version}.tar.bz2
#squidf: fix opencv test version for MGA
Patch0:		siril-fix-opencv-version.patch
Patch1:		siril-skip-update-check.patch
BuildRequires:	appstream-util
#squidf: log complains about it otherwise
BuildRequires:	cmake
BuildRequires:	meson
BuildRequires:	gettext
BuildRequires:	git-core
BuildRequires:	intltool
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	pkgconfig(exiv2)
BuildRequires:	pkgconfig(ffms2)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(gtk+-3.0)
#squidf: added based on Gitlab doc
BuildRequires:	pkgconfig(gtkextra-3.0)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libconfig)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libswresample)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(rtprocess)
BuildRequires:	pkgconfig(wcslib)

Recommends:	gnuplot

%description
Siril is an image processing tool specially tailored for noise reduction and
improving the signal/noise ratio of an image from multiple captures, as
required in astronomy. Siril can align automatically or manually, stack and
enhance pictures from various file formats, even images sequences (movies and
SER files).

%prep
%autosetup -p1

%build
# override build directory, the default "build" is a regular source directory
%define _vpath_builddir build-%{_build_arch}

%meson -D enable-libcurl=yes \
       -D libconfig=true
%meson_build

%install
%meson_install

%find_lang %{name}

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m 0644 pixmaps/siril.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/siril.svg

%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/org.siril.Siril.appdata.xml

%files -f %{name}.lang
%doc AUTHORS NEWS README.md
#squidf: license complement
%license LICENSE.md LICENSE_sleef.txt
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%{_datadir}/%{name}/
%{_datadir}/applications/org.siril.Siril.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_metainfodir}/org.siril.Siril.appdata.xml
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/mimetypes/*.svg
%{_iconsdir}/hicolor/symbolic/apps/org.siril.Siril-symbolic.svg
%{_iconsdir}/hicolor/*/apps/org.siril.Siril.svg
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-cli.1*
#squidf: licenses are packaged with %%license
%exclude %{_docdir}/%{name}/LICENSE.md
%exclude %{_docdir}/%{name}/LICENSE_sleef.txt


%changelog
* Mon Dec 30 2024 daviddavid <daviddavid> 1.2.5-2.mga10
+ Revision: 2131681
- rebuild for new libraw 0.21.3

* Mon Dec 09 2024 daviddavid <daviddavid> 1.2.5-1.mga10
+ Revision: 2122973
- new version: 1.2.5

* Sun Dec 08 2024 daviddavid <daviddavid> 1.2.4-2.mga10
+ Revision: 2122653
- rebuild for new ffmpeg 7.1

* Sat Sep 14 2024 daviddavid <daviddavid> 1.2.4-1.mga10
+ Revision: 2096217
- new version: 1.2.4
- rebuild for new opencv 4.10.0

* Thu Jun 20 2024 daviddavid <daviddavid> 1.2.3-1.mga10
+ Revision: 2075803
- new version: 1.2.3

* Sat Jun 15 2024 daviddavid <daviddavid> 1.2.2-1.mga10
+ Revision: 2074451
- new version: 1.2.2

* Tue Feb 06 2024 daviddavid <daviddavid> 1.2.1-1.mga10
+ Revision: 2037917
- new version: 1.2.1
- remove merged upstream patch

* Thu Jan 04 2024 daviddavid <daviddavid> 1.2.0-3.mga10
+ Revision: 2027403
- rebuild for new wcslib

* Mon Oct 09 2023 daviddavid <daviddavid> 1.2.0-2.mga10
+ Revision: 1993766
- add upstream patch to fix build with exiv2 >= 0.28
- rebuild for new exiv2 0.28.0

* Mon Sep 18 2023 daviddavid <daviddavid> 1.2.0-1.mga10
+ Revision: 1987922
- new version: 1.2.0

* Thu Dec 29 2022 daviddavid <daviddavid> 1.0.6-6.mga9
+ Revision: 1927533
- rebuild for new gsl 2.7.1

* Mon Dec 12 2022 ns80 <ns80> 1.0.6-5.mga9
+ Revision: 1921117
- rebuild for new libtiff

* Sun Dec 04 2022 daviddavid <daviddavid> 1.0.6-4.mga9
+ Revision: 1917601
- rebuild for new cfitsio 4.2.0

* Wed Nov 02 2022 ghibo <ghibo> 1.0.6-3.mga9
+ Revision: 1901482
- Rebuild for newer opencv

* Tue Nov 01 2022 ghibo <ghibo> 1.0.6-2.mga9
+ Revision: 1900946
- Rebuild against opencv 4.6.0

* Thu Oct 20 2022 squidf <squidf> 1.0.6-1.mga9
+ Revision: 1898096
- New version: 1.0.6

* Sat Sep 10 2022 papoteur <papoteur> 1.0.5-1.mga9
+ Revision: 1886486
- new 1.0.5

* Sat Sep 03 2022 squidf <squidf> 1.0.4-1.mga9
+ Revision: 1883686
- New version: 1.0.4

* Mon Jul 04 2022 squidf <squidf> 1.0.3-1.mga9
+ Revision: 1867644
- New version: 1.0.3

* Sun Jun 05 2022 wally <wally> 1.0.2-2.mga9
+ Revision: 1861308
- enable libcurl support for web access without gvfs (mga#30508)

* Sat Jun 04 2022 wally <wally> 1.0.2-1.mga9
+ Revision: 1861187
- new version 1.0.2
- skip upstream version check
- update URL

* Mon Apr 18 2022 squidf <squidf> 1.0.1-1.mga9
+ Revision: 1851435
- New version: 1.0.1
- Update fix-opencv-version patch
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Fri Mar 11 2022 squidf <squidf> 1.0.0-1.mga9
+ Revision: 1790432
- First stable version
- New version: 1.0.0 (mga#29376)
- Handle LICENSE_sleef.txt location
- Remove curl build dependency
- Add cmake and gtkextra-3.0 build dependencies
- Add opencv test patch to fix build

* Mon Dec 27 2021 wally <wally> 0.99.8.1-3.mga9
+ Revision: 1764542
- rebuild for opencv 4.5.5

* Fri Apr 23 2021 daviddavid <daviddavid> 0.99.8.1-2.mga9
+ Revision: 1718156
- add upstream patch to fix build with glib2 >= 2.68

* Thu Feb 25 2021 daviddavid <daviddavid> 0.99.8.1-1.mga9
+ Revision: 1691000
- new version: 0.99.8.1

* Fri Oct 30 2020 joequant <joequant> 0.99.6-3.mga8
+ Revision: 1640715
- rebuild with opencv

* Fri Oct 23 2020 daviddavid <daviddavid> 0.99.6-2.mga8
+ Revision: 1638687
- switch to meson build system

* Fri Oct 23 2020 daviddavid <daviddavid> 0.99.6-1.mga8
+ Revision: 1638681
- new version: 0.99.6

* Wed Sep 09 2020 zezinho <zezinho> 0.99.4-2.mga8
+ Revision: 1623895
- rebuild against libraw20

* Tue Aug 18 2020 daviddavid <daviddavid> 0.99.4-1.mga8
+ Revision: 1614721
- new version: 0.99.4
- remove merged upstream patch
- enable exiv2, libheif and rtprocess support

* Thu Jul 23 2020 daviddavid <daviddavid> 0.9.12-6.mga8
+ Revision: 1608164
- rebuild for new cfitsio 3.480

* Tue Jun 02 2020 daviddavid <daviddavid> 0.9.12-5.mga8
+ Revision: 1589683
- add upstream patch to fix build with gcc 10

* Fri Mar 27 2020 daviddavid <daviddavid> 0.9.12-4.mga8
+ Revision: 1560894
- rebuild for new cfitsio 3.470

* Wed Feb 19 2020 umeabot <umeabot> 0.9.12-3.mga8
+ Revision: 1544335
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 0.9.12-2.mga8
+ Revision: 1482894
- rebuild for new opencv 4.2.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Nov 04 2019 daviddavid <daviddavid> 0.9.12-1.mga8
+ Revision: 1457576
- new version: 0.9.12

* Tue Aug 27 2019 daviddavid <daviddavid> 0.9.11-2.mga8
+ Revision: 1433787
- rebuild for new gsl 2.6

* Sun Jun 30 2019 daviddavid <daviddavid> 0.9.11-1.mga8
+ Revision: 1416309
- new version: 0.9.11

* Fri Jan 18 2019 daviddavid <daviddavid> 0.9.10-1.mga7
+ Revision: 1357855
- new version: 0.9.10

* Thu Sep 06 2018 daviddavid <daviddavid> 0.9.9-2.mga7
+ Revision: 1257571
- add patch to fix build with new glibc
- rebuild for new libraw 0.19.0

* Thu Jun 07 2018 daviddavid <daviddavid> 0.9.9-1.mga7
+ Revision: 1235111
- new version: 0.9.9

* Sun May 13 2018 daviddavid <daviddavid> 0.9.8.3-6.mga7
+ Revision: 1228731
- rebuild for new cfitsio 3.450

* Thu Apr 26 2018 daviddavid <daviddavid> 0.9.8.3-5.mga7
+ Revision: 1222571
- rebuild for new ffmpeg 4.0

* Thu Apr 12 2018 daviddavid <daviddavid> 0.9.8.3-4.mga7
+ Revision: 1217796
- rebuild for new opencv 3.4.1

* Fri Apr 06 2018 kekepower <kekepower> 0.9.8.3-3.mga7
+ Revision: 1215673
- Rebuild for new libconfig

* Tue Feb 20 2018 daviddavid <daviddavid> 0.9.8.3-1.mga7
+ Revision: 1203605
- new version: 0.9.8.3
- remove merged upstream patch

* Wed Jan 31 2018 daviddavid <daviddavid> 0.9.8-1.mga7
+ Revision: 1198295
- new version: 0.9.8

* Sat Dec 23 2017 daviddavid <daviddavid> 0.9.7-2.mga7
+ Revision: 1184169
- rebuild for new gsl

* Sat Oct 07 2017 daviddavid <daviddavid> 0.9.7-1.mga7
+ Revision: 1169994
- new version: 0.9.7
- rename and rediff mga-install patch

* Sat Jul 01 2017 daviddavid <daviddavid> 0.9.6-1.mga6
+ Revision: 1108826
- new version: 0.9.6
- recommends gnuplot

* Tue May 02 2017 akien <akien> 0.9.5-4.mga6
+ Revision: 1098375
- Rebuild for ffmpeg 3.3

* Thu Mar 09 2017 daviddavid <daviddavid> 0.9.5-3.mga6
+ Revision: 1091138
- rebuild for ffmpeg 3.2.4

* Wed Dec 28 2016 neoclust <neoclust> 0.9.5-2.mga6
+ Revision: 1078460
- Rebuild for new libraw

* Tue Nov 29 2016 daviddavid <daviddavid> 0.9.5-1.mga6
+ Revision: 1070993
- fix release tag
- new version: 0.9.5
- rename and rediff mga-install patch

* Tue Nov 22 2016 eatdirt <eatdirt> 0.9.4-4.mga6
+ Revision: 1068813
- Rebuild for new cfitsio

* Thu Sep 15 2016 daviddavid <daviddavid> 0.9.4-3.mga6
+ Revision: 1052979
- use a new set of icons (thanks to the developer lock042)

* Sun Sep 11 2016 daviddavid <daviddavid> 0.9.4-2.mga6
+ Revision: 1051440
- update desktop file categories from upstream

* Fri Sep 09 2016 daviddavid <daviddavid> 0.9.4-1.mga6
+ Revision: 1051048
- initial package siril

